import { AxpConversationCore } from '@avaya/axp-client-sdk-core';
import { Constructable } from '@avaya/axp-client-sdk-core';
import * as jquery from 'jquery';

/**
 * AxpAudioInputInterface provides functionality for managing the audio input device that is used by the user (microphone).
 * @public
 */
export declare interface AxpAudioInputInterface extends AxpMediaInterface {
    /**
     * Sets the volume of the audio input device
     * @param {number} volume between 0.0 and 1.0
     */
    setVolume(volume: number): any;
    /**
     * @returns {number} The volume of the audio input device
     */
    getVolume(): number;
}

/**
 * AxpAudioInterface provides functionality for managing the audio device that is used by the user.
 * It allows to access to either the audio input interface (microphone) or the audio output interface (headphones).
 * @public
 */
export declare interface AxpAudioInterface {
    /**
     * @returns {AxpAudioOutputInterface} The audio output interface
     */
    getOutputInterface(): AxpAudioOutputInterface;
    /**
     * @returns {AxpAudioInputInterface} The audio input interface
     */
    getInputInterface(): AxpAudioInputInterface;
}

/**
 * AxpAudioMode
 * @public
 */
export declare enum AxpAudioMode {
    SEND_RECEIVE = "SEND_RECEIVE",
    DISABLE = "DISABLE",
    ENABLE = "ENABLE"
}

/**
 * AxpAudioOutputInterface provides functionality for managing the audio output device that is used by the user (headphones).
 * @public
 */
export declare interface AxpAudioOutputInterface extends AxpMediaInterface {
    /**
     * Mutes audio output device
     */
    mute(): void;
    /**
     * Unmutes audio output device
     */
    unmute(): void;
    /**
     * @returns {boolean} True if audio output device is muted; otherwise, false.
     */
    isMuted(): boolean;
}

/**
 * AxpCall interface
 * @public
 */
export declare interface AxpCall {
    /**
     * Ends the call
     */
    end(): void;
    /**
     * Starts the call
     */
    start(): void;
    /**
     * Returns the call id
     */
    getCallId(): string;
    /**
     * Returns the call estabsliehd time
     */
    getEstablishedTime(): Date;
    /**
     * Returns true if audio is muted; otherwise, false.
     */
    isAudioMuted(): boolean;
    /**
     * Returns true if the call media is connected; otherwise, false.
     */
    isMediaConnected(): boolean;
    /**
     * Returns true if the speaker is muted; otherwise, false.
     */
    isSpeakerMuted(): boolean;
    /**
     * Returns true if service is available; otherwise, false.
     */
    isServiceAvailable(): boolean;
    /**
     * Enables the microphone
     */
    enableMic(): Promise<void | AxpCallException>;
    /**
     * Disables the microphone
     */
    disableMic(): Promise<void | AxpCallException>;
    /**
     * Mutes the audio
     */
    muteAudio(): Promise<void | AxpCallException>;
    /**
     * Unmutes the audio
     */
    unmuteAudio(): Promise<void | AxpCallException>;
    /**
     * Mutes the speaker
     */
    muteSpeaker(): Promise<void | AxpCallException>;
    /**
     * Unmutes the speaker
     */
    unmuteSpeaker(): Promise<void | AxpCallException>;
    /**
     * Sends DTMF tone
     * @param {AxpDtmfTone} dtmf
     */
    sendDTMF(dtmf: AxpDtmfTone): Promise<void | AxpCallException>;
    /**
     * Sets or changes the audio mode
     * @param {AxpAudioMode} audioMode
     */
    setAudioMode(audioMode: AxpAudioMode): Promise<void | AxpCallException>;
    setWebCollaboration(enabled: boolean): Promise<void | AxpCallException>;
    /**
     * Sets the noise reduction setting
     * @param {AxpNoiseReductionSetting} setting
     */
    setNoiseReductionSetting(setting: AxpNoiseReductionSetting): Promise<void | AxpCallException>;
    /**
     * Adds a callback function to be invoked when the call is started.
     * @param {function} callback
     */
    addOnCallStartedCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when the call is ended.
     * @param {function} callback
     */
    addOnCallEndedCallback(callback: (call: AxpCall, event: AxpEndCallEvent) => void): void;
    /**
     * Adds a callback function to be invoked when the call is established.
     * @param {function} callback
     */
    addOnCallEstablishedCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when the call service is available.
     * @param {function} callback
     */
    addOnCallServiceAvailableCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when the call service is unavailable.
     * @param {function} callback
     */
    addOnCallServiceUnavailableCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when media is connected.
     * @param {function} callback
     */
    addOnMediaConnectedCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when media is disconnected.
     * @param {function} callback
     */
    addOnMediaDisconnectedCallback(callback: (call: AxpCall) => void): void;
    /**
     * Adds a callback function to be invoked when there is a call failure.
     * @param {function} callback
     */
    addOnCallFailedCallback(callback: (call: AxpCall, exception: AxpCallException) => void): void;
    /**
     * Adds a callback function to be invoked when media failed, i.e. no longer available until it is recovered.
     * @param {function} callback
     */
    addOnMediaFailedCallback(callback: (call: AxpCall) => void): void;
    removeOnCallStartedCallback(callback: (event: any) => void): void;
    removeOnCallEndedCallback(callback: (event: any) => void): void;
    removeOnCallEstablishedCallback(callback: (event: any) => void): void;
    removeOnCallFailedCallback(callback: (event: any) => void): void;
    removeOnCallServiceAvailableCallback(callback: (event: any) => void): void;
    removeOnCallServiceUnavailableCallback(callback: (event: any) => void): void;
    removeOnMediaFailedCallback(callback: (event: any) => void): void;
}

/**
 * AxpCallError reasons
 * @public
 */
export declare enum AxpCallError {
    /**
     * Reported when local user's authentication with the network has failed. This can happen when user-supplied credentials do not match the credentials the server expects to receive from the end user.
     */
    AUTHENTICATION_ERROR = "AUTHENTICATION_ERROR",
    /**
     * Reported when a request by the client to start, accept or unhold a call results in an automatic hold of another currently active call and that hold operation fails.
     */
    AUTO_HOLD_FAILED = "AUTO_HOLD_FAILED",
    /**
     * Reported when the request is rejected by the server due to resource being busy.
     * For example, a point-to-point call may fail if the called party returns a busy indication, or if there are no local line appearances available on the server side to initiate the call.
     */
    BUSY = "BUSY",
    /**
     * Reported when the request cannot be supported at the moment due to the current state of the call.
     * For example, a hold request while the call is being transferred, is not allowed.
     */
    CALL_STATE_MISMATCH = "CALL_STATE_MISMATCH",
    /**
     * Call is not found.
     */
    CALL_NOT_FOUND = "CALL_NOT_FOUND",
    /**
     * Current operation is cancelled.
     */
    CANCELLED = "CANCELLED",
    /**
     * Operation is not allowed currently.
     */
    CAPABILITY_NOT_ALLOWED = "CAPABILITY_NOT_ALLOWED",
    /**
     * Reported when a VoIP session cannot be established due to incompatibility of codecs between the local and remote parties.
     */
    CODEC_MISMATCH = "CODEC_MISMATCH",
    /**
     * Media devices are not found.
     */
    DEVICES_NOT_FOUND = "DEVICES_NOT_FOUND",
    /**
     * Microphone is not found.
     */
    MICROPHONE_NOT_FOUND = "MICROPHONE_NOT_FOUND",
    /**
     * Microphone permission denied
     */
    MICROPHONE_PERMISSION_DENIED = "MICROPHONE_PERMISSION_DENIED",
    /**
     * Microphone is not accessible.
     */
    MICROPHONE_NOT_ACCESSIBLE = "MICROPHONE_NOT_ACCESSIBLE",
    /**
     * Speakers are not found.
     */
    SPEAKERS_NOT_FOUND = "SPEAKERS_NOT_FOUND",
    /**
     * Camera is not found.
     */
    CAMERA_NOT_FOUND = "CAMERA_NOT_FOUND",
    /**
     * Camera permission denied
     */
    CAMERA_PERMISSION_DENIED = "CAMERA_PERMISSION_DENIED",
    /**
     * Camera is not accessible.
     */
    CAMERA_NOT_ACCESSIBLE = "CAMERA_NOT_ACCESSIBLE",
    /**
     * Camera didn't initialize until allowedCameraInitDelay milliseconds after the call was established.
     */
    CAMERA_INITIALIZED_LATE = "CAMERA_INITIALIZED_LATE",
    /**
     * Operation has failed. The failure reason was not specified.
     */
    FAILED = "FAILED",
    /**
     * Edge Turn TLS/TCP error.
     */
    TCP_TLS_TURN_NOT_SUPPORTED = "TCP_TLS_TURN_NOT_SUPPORTED",
    /**
     * Call is ended.
     */
    ENDED = "ENDED",
    /**
     * Operation has failed because another call operation is in progress.
     */
    IN_PROGRESS = "IN_PROGRESS",
    /**
     * Operation has failed due to an internal error.
     * For example, if the network connection is lost after the API call is made by the application but before the API call can be processed, this error code is returned.
     */
    INTERNAL_ERROR = "INTERNAL_ERROR",
    /**
     * Reported when an invalid parameter is used for the request.
     * For example, if the application tries to add a participant but provides an empty participant address, this error is reported.
     */
    INVALID_PARAMETER = "INVALID_PARAMETER",
    /**
     * Reported when a line reservation attempt is failed by the server. It should be noted that the line appearance id and the line appearance owner are required to reserve a line appearance when the call is initiated on a bridged line appearance.
     * If, for some reason, the line reservation request fails, this error code is reported.
     * This error code is only applicable to communication system environments where bridging and bridged line appearances are supported.
     */
    LINE_RESERVATION_ERROR = "LINE_RESERVATION_ERROR",
    /**
     * Reported when local audio and/or video resources cannot be initialized successfully.
     */
    MEDIA_CREATION_FAILURE = "MEDIA_CREATION_FAILURE",
    /**
     * Reported when local audio and/or video resources cannot be started successfully.
     */
    MEDIA_START_FAILURE = "MEDIA_START_FAILURE",
    /**
     * Reported when the call server doesn't support multiple simultaneous calls.
     */
    MULTIPLE_CALLS_NOT_SUPPORTED = "MULTIPLE_CALLS_NOT_SUPPORTED",
    /**
     * Reported when audio and/or video resources connection failed.
     */
    MEDIA_PATH_FAILURE = "MEDIA_PATH_FAILURE",
    /**
     * Multiple video channels are not supported.
     */
    MULTIPLE_VIDEO_CHANNELS_NOT_SUPPORTED = "MULTIPLE_VIDEO_CHANNELS_NOT_SUPPORTED",
    /**
     * Mute state mismatch.
     */
    MUTE_STATE_MISMATCH = "MUTE_STATE_MISMATCH",
    /**
     * Reported when the local user call initiation attempt fails because the Avaya Communication Manager has no idle line appearance available for the call.
     */
    NO_AVAILABLE_CALL_APPEARANCE = "NO_AVAILABLE_CALL_APPEARANCE",
    /**
     * Reported when add or remove operations of the participant cannot be supported because the local user does not have moderator privileges to perform these actions.
     */
    NOT_AUTHORIZED = "NOT_AUTHORIZED",
    /**
     * Reported when the called party address is not known to the server.
     * For example, if the user dials an invalid telephone number, this error code is reported.
     */
    NOT_FOUND = "NOT_FOUND",
    /**
     * Reported when an operation is denied because the user does not have the license to perform the operation.
     * For example, a video add request may be denied using this error code when the user account is not licensed to support video calls.
     */
    NOT_LICENSED = "NOT_LICENSED",
    /**
     * Reported when an operation fails because the server assumes that the user is not registered.
     */
    NOT_REGISTERED = "NOT_REGISTERED",
    /**
     * Reported when no acceptable device constraint is found.
     */
    OVERCONSTRAINED = "OVERCONSTRAINED",
    /**
     * Operation was redirected to another destination.
     */
    REDIRECTED = "REDIRECTED",
    /**
     * Reported when an attempt to register call services is rejected most likely due to maximum device limits has reached.
     */
    REGISTRATION_TERMINATED = "REGISTRATION_TERMINATED",
    /**
     * Reported when an attempt to answer an incoming call locally at a remote extension (e.g., at a bridged line appearance extension) has failed because the call was already answered remotely.
     */
    REMOTE_CALL_NOT_ALERTING = "REMOTE_CALL_NOT_ALERTING",
    /**
     * Reported when the application tries to accept an incoming call, but this attempt fails because the remote audio and/or video information could not be applied to local audio/video resources.
     */
    REMOTE_MEDIA_PROCESSING_FAILURE = "REMOTE_MEDIA_PROCESSING_FAILURE",
    /**
     * Reported when a network message could not be sent due to a network connection error.
     */
    SEND_ERROR = "SEND_ERROR",
    /**
     * Reported when the request has failed due to an internal server error.
     */
    SERVER_ERROR = "SERVER_ERROR",
    /**
     * Reported when an invalid or expired sessionId is used for an MPaaS call.
     */
    SESSION_ID_NOT_FOUND = "SESSION_ID_NOT_FOUND",
    /**
     * Reported when the same sessionId is used for two MPaaS calls at the same time.
     */
    SESSION_ID_ALREADY_CONNECTED = "SESSION_ID_ALREADY_CONNECTED",
    /**
     * Operation completed successfully. This return code is not used.
     */
    SUCCESS = "SUCCESS",
    /**
     * Reported when local time-out occurs while sending a network message or a response to the message was not received from the server in time.
     */
    TIMEOUT = "TIMEOUT",
    /**
     * Reported when no ice candidates are found after ice gathering time elapsed
     */
    ICE_GATHERING_TIMEOUT = "ICE_GATHERING_TIMEOUT",
    /**
     * Reported when the request could not be sent to the network server.
     */
    TRANSPORT_ERROR = "TRANSPORT_ERROR",
    /**
     * Unhandled video direction.
     */
    UNHANDLED_VIDEO_DIRECTION = "UNHANDLED_VIDEO_DIRECTION",
    /**
     * Reported when the called party address is not known to the server.
     * For example, if the user dials an invalid telephone number, this error code is reported.
     */
    USER_NOT_FOUND = "USER_NOT_FOUND",
    /**
     * Reported when the called party has no device registered on his/her behalf, thus, making call setup not possible at this point in time.
     */
    USER_TEMPORARILY_UNAVAILABLE = "USER_TEMPORARILY_UNAVAILABLE",
    /**
     * Reported when a mid-call video add request was denied by the remote party.
     */
    VIDEO_DENIED = "VIDEO_DENIED",
    /**
     * Reported when browser does not support video deescalation from a remote endpoint/gateway.
     */
    VIDEO_DEESCALATION_NOT_SUPPORTED = "VIDEO_DEESCALATION_NOT_SUPPORTED",
    /**
     * WEBRTC is not supported by the browser.
     */
    WEBRTC_NOT_SUPPORTED = "WEBRTC_NOT_SUPPORTED",
    /**
     * Statistics information is unavailable.
     */
    STATISTICS_UNAVAILABLE = "STATISTICS_UNAVAILABLE",
    /**
     * Signaling path for the call has failed but media is preserved.
     */
    MEDIA_PRESERVED = "MEDIA_PRESERVED",
    /**
     * Reported when service is temporarily unavailable.
     */
    SERVICE_TEMPORARILY_UNAVAILABLE = "SERVICE_TEMPORARILY_UNAVAILABLE",
    /**
     * Reported when service is unavailable.
     */
    SERVICE_UNAVAILABLE = "SERVICE_UNAVAILABLE",
    /**
     * Video only call is not supported.
     */
    VIDEO_ONLY_CALL_NOT_SUPPORTED = "VIDEO_ONLY_CALL_NOT_SUPPORTED",
    /**
     * Video was rejected by far-end and the browser does not support reverting to audio only.
     */
    VIDEO_REJECTION_NOT_SUPPORTED = "VIDEO_REJECTION_NOT_SUPPORTED",
    /**
     * Collaboration only call is not supported.
     */
    COLLABORATION_ONLY_CALL_NOT_SUPPORTED = "COLLABORATION_ONLY_CALL_NOT_SUPPORTED",
    /**
     * Network events url to subscriptions is undefined
     */
    NETWORK_EVENTS_SUBSCRIPTION_UNAVAILABLE = "NETWORK_EVENTS_SUBSCRIPTION_UNAVAILABLE",
    /**
     * Network events subscriptions request failed
     */
    NETWORK_EVENTS_SUBSCRIPTION_FAILED = "NETWORK_EVENTS_SUBSCRIPTION_FAILED",
    /**
     * Media service is unavailable.
     */
    MEDIA_SERVICE_UNAVAILABLE = "MEDIA_SERVICE_UNAVAILABLE",
    /**
     * Invalid events to subscribe.
     */
    INVALID_ACCEPTED_EVENTS = "INVALID_ACCEPTED_EVENTS",
    /**
     * VDI service is unavailable
     */
    VDI_UNAVAILABLE = "VDI_UNAVAILABLE"
}

/**
 * AxpCallException interface
 * @public
 */
export declare interface AxpCallException {
    /**
     * Returns the error code
     * @returns {AxpCallError} The error code
     */
    getError(): AxpCallError;
    getProtocolType(): string;
    getProtocolErrorCode(): number;
    getProtocolErrorReason(): string;
}

/**
 * AxpCalling namespace
 * @public
 */
export declare namespace AxpCalling {
    /**
     * @returns {string} The version of the AXP Calling module.
     */
    export function version(): string;
    /**
     * @returns {boolean} True if the service is available; otherwise, false.
     */
    export function isServiceAvailable(): boolean;
    /**
     * @returns {Promise<AxpMediaServices>} The media engine
     * @throws {Error} If the Calling service is not initialized.
     */
    export function getMediaEngine(): Promise<AxpMediaServices>;
}

/**
 * Builder class for AxpCallingConfigTrait
 * @public
 */
export declare class AxpCallingConfigBuilder {
    #private;
    constructor();
    enableVideo(): AxpCallingConfigBuilder;
    enableCollaboration(): AxpCallingConfigBuilder;
    /**
     * Builds the AxpCallingConfigTrait
     * @returns {AxpCallingConfigTrait}
     */
    build(): AxpCallingConfigTrait;
}

/****************************************************************************
 * Copyright 2024 Avaya LLC, All Rights Reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Avaya LLC
 * The copyright notice above does not evidence any actual or intended
 * publication of such source code.
 * Some third-party source code components may have been modified from their
 * original versions by Avaya LLC
 * The modifications are Copyright 2023-2024 Avaya LLC, All Rights Reserved.
 * Avaya - Confidential & Restricted. May not be distributed further without
 * written permission of the Avaya owner.
 ****************************************************************************/
/**
 * @public
 */
export declare interface AxpCallingConfigTrait {
    isVideoEnabled(): boolean;
    isCollaborationEnabled(): boolean;
}

/**
 * @public
 * A mixin that adds calling capabilities to the {@link AxpConversationCore} class.
 * @returns A new class that extends the {@link AxpConversationCore} class with calling capabilities.
 */
export declare function AxpCallingConversation(): Constructable<AxpConversationCore> & Constructable<AxpCallingConversationTrait>;

/**
 * @public
 * A mixin that adds calling capabilities to the provided base class which should be a sub class of {@link AxpConversationCore} class.
 * @param BaseFunctionality The base class to extend. The base class must be subclass of {@link AxpConversationCore}.
 * @returns A new class that extends the base class with calling capabilities.
 */
export declare function AxpCallingConversation<T extends Constructable<AxpConversationCore>>(BaseFunctionality: T): Constructable<AxpCallingConversationTrait> & T;

/**
 * AxpCalling conversation interface
 * @public
 */
export declare interface AxpCallingConversationTrait {
    /**
     * Creates and starts a call
     * @param {AxpCallRequestConfigTrait} callRequest Optional call request configuration
     * @param {function} setupCallbacks Optional callback to setup call event handlers
     * @returns {Promise<AxpCall>} The established call
     */
    addCall(callRequest?: AxpCallRequestConfigTrait, setupCallbacks?: (call: AxpCall) => void): Promise<AxpCall>;
}

/**
 * Builder class for AxpCallRequestConfigTrait
 * @public
 */
export declare class AxpCallRequestBuilder {
    #private;
    constructor();
    /**
     * @description Enables audio noise reduction
     * @returns {AxpCallRequestBuilder}
     */
    enableAudioNoiseReduction(): AxpCallRequestBuilder;
    /**
     * @private
     * TODO: Enable collaboration when feature is supported
     */
    enableCollaboration(): AxpCallRequestBuilder;
    /**
     * @description Sets as priority call
     * @returns {AxpCallRequestBuilder}
     */
    isPriority(): AxpCallRequestBuilder;
    /**
     * @description Mutes audio
     * @returns {AxpCallRequestBuilder}
     */
    muteAudio(): AxpCallRequestBuilder;
    /**
     * @description Mutes video
     * @returns {AxpCallRequestBuilder}
     */
    muteVideo(): AxpCallRequestBuilder;
    /**
     * @description Sets E.164 remote address
     * @param {string} address Remote address
     * @returns
     */
    setRemoteAddress(address: string): AxpCallRequestBuilder;
    /**
     * @description Builds the call request configuration
     * @returns {AxpCallRequestConfigTrait}
     */
    build(): AxpCallRequestConfigTrait;
}

/****************************************************************************
 * Copyright 2024 Avaya LLC, All Rights Reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Avaya LLC
 * The copyright notice above does not evidence any actual or intended
 * publication of such source code.
 * Some third-party source code components may have been modified from their
 * original versions by Avaya LLC
 * The modifications are Copyright 2023-2024 Avaya LLC, All Rights Reserved.
 * Avaya - Confidential & Restricted. May not be distributed further without
 * written permission of the Avaya owner.
 ****************************************************************************/
/**
 * @public
 */
export declare interface AxpCallRequestConfigTrait {
    isMuteAudio(): boolean;
    isMuteVideo(): boolean;
    isPriority(): boolean;
    isEnableCollaboration(): boolean;
    isEnableAudioNoiseReduction(): boolean;
    getRemoteAddress(): string;
}

/**
 * AxpDtmfTone type
 * @public
 */
export declare type AxpDtmfTone = "0" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "*" | "#" | "A" | "B" | "C" | "D";

/**
 * @public
 */
export declare interface AxpEndCallEvent {
    /**
     * Returns the reason for the call ending
     */
    getReason(): string;
    getReasonProtocol(): string;
    getReasonCause(): number;
    getReasonText(): string;
}

/****************************************************************************
 * Copyright 2024 Avaya LLC, All Rights Reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Avaya LLC
 * The copyright notice above does not evidence any actual or intended
 * publication of such source code.
 * Some third-party source code components may have been modified from their
 * original versions by Avaya LLC
 * The modifications are Copyright 2023-2024 Avaya LLC, All Rights Reserved.
 * Avaya - Confidential & Restricted. May not be distributed further without
 * written permission of the Avaya owner.
 ****************************************************************************/
/**
 * AxpMediaDevice represents a media device
 * @public
 */
export declare interface AxpMediaDevice {
    /**
     * @returns {string} The device id
     */
    getDeviceId(): string;
    /**
     * @returns {string} The device groupd id
     */
    getGroupId(): string;
    /**
     * @returns {string} The device label
     */
    getLabel(): string;
}

/**
 * AxpMediaDirection
 * @public
 */
export declare enum AxpMediaDirection {
    RECV_ONLY = "recvonly",
    SEND_ONLY = "sendonly",
    SEND_RECV = "sendrecv",
    INACTIVE = "inactive",
    DISABLE = "disable",
    UNDEFINED = "undefined"
}

/**
 * AxpMediaInterface represents a media interface
 * @public
 */
export declare interface AxpMediaInterface {
    /**
     * @returns {AxpMediaDevice[]} The available devices
     */
    getAvailableDevices(): AxpMediaDevice[];
    /**
     * @returns {boolean} True if there are available devices
     */
    hasAvailableDevices(): boolean;
    /**
     * Selects a media device
     * @param {AxpMediaDevice} device
     */
    setSelectedDevice(device: AxpMediaDevice): void;
    /**
     * @returns {AxpMediaDevice} The selected device
     */
    getSelectedDevice(): AxpMediaDevice;
    /**
     * Adds a callback to be invoked when devices are added
     * @param {function} callback
     */
    addOnDevicesAddedCallback(callback: (mediaInterface: AxpMediaInterface, devices: AxpMediaDevice[]) => void): void;
    /**
     * Adds a callback to be invoked when devices are removed
     * @param {function} callback
     */
    addOnDevicesRemovedCallback(callback: (mediaInterface: AxpMediaInterface, devices: AxpMediaDevice[]) => void): void;
    /**
     * Adds a callback to be invoked when selected device has changed
     * @param {function} callback
     */
    addOnSelectedDeviceChangedCallback(callback: (mediaInterface: AxpMediaInterface, device: AxpMediaDevice) => void): void;
    /**
     * Adds a callback to be invoked when selected device has removed
     * @param {function} callback
     */
    addOnSelectedDeviceRemovedCallback(callback: (mediaInterface: AxpMediaInterface, device: AxpMediaDevice) => void): void;
    /**
     * Adds a callback to be invoked when all devices are unavailable
     * @param {function} callback
     */
    addOnDevicesUnavailableCallback(callback: (mediaInterface: AxpMediaInterface) => void): void;
}

/**
 * AxpMediaServices provides functionality of the audio management.
 * It allows to access to either the audio interface.
 * @public
 */
export declare interface AxpMediaServices {
    /**
     * @returns {AxpAudioInterface} The audio interface
     */
    getAudioInterface(): AxpAudioInterface;
}

/**
 * AxpNoiseReductionSetting
 * @public
 */
export declare enum AxpNoiseReductionSetting {
    ENABLED = "ENABLED",
    DISABLE_CLIENT = "DISABLE_CLIENT",
    PREFER_CLIENT = "PREFER_CLIENT",
    DISABLE_ALL = "DISABLE_ALL"
}

/**
 * Builder class for AxpOnNetworkEventTrait
 * @public
 */
export declare class AxpOnNetworkEventBuilder {
    #private;
    constructor();
    /**
     * Adds a category for monitoring the onNetworkEvent
     * @param {string} category
     * @returns
     */
    addCategory(category: string): AxpOnNetworkEventBuilder;
    /**
     * Adds an event for monitoring the onNetworkEvent
     * @param {string} event
     * @returns
     */
    addEvent(event: string): AxpOnNetworkEventBuilder;
    /**
     * Excludes an event from monitoring the onNetworkEvent
     * @param {string} event
     * @returns
     */
    excludeEvent(event: string): AxpOnNetworkEventBuilder;
    /**
     * Builds the AxpOnNetworkEventTrait
     * @returns {AxpOnNetworkEventTrait}
     */
    build(): AxpOnNetworkEventTrait;
}

/****************************************************************************
 * Copyright 2024 Avaya LLC, All Rights Reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Avaya LLC
 * The copyright notice above does not evidence any actual or intended
 * publication of such source code.
 * Some third-party source code components may have been modified from their
 * original versions by Avaya LLC
 * The modifications are Copyright 2023-2024 Avaya LLC, All Rights Reserved.
 * Avaya - Confidential & Restricted. May not be distributed further without
 * written permission of the Avaya owner.
 ****************************************************************************/
/**
 * @public
 */
export declare interface AxpOnNetworkEventTrait {
    getCategories(): string[];
    getEvents(): string[];
    getExcludedEvents(): string[];
}

export { jquery }

export { }
